# Tranquilo

[![image](https://img.shields.io/pypi/v/tranquilo?color=blue)](https://pypi.org/project/tranquilo)
[![image](https://img.shields.io/pypi/pyversions/tranquilo)](https://pypi.org/project/tranquilo)
[![image](https://img.shields.io/conda/vn/conda-forge/tranquilo.svg)](https://anaconda.org/conda-forge/tranquilo)
[![image](https://img.shields.io/conda/pn/conda-forge/tranquilo.svg)](https://anaconda.org/conda-forge/tranquilo)
[![image](https://img.shields.io/pypi/l/tranquilo)](https://pypi.org/project/tranquilo)
[![image](https://readthedocs.org/projects/tranquilo/badge/?version=latest)](https://tranquilo.readthedocs.io/en/latest)
[![image](https://img.shields.io/github/actions/workflow/status/OpenSourceEconomics/tranquilo/main.yml?branch=main)](https://github.com/OpenSourceEconomics/tranquilo/actions?query=branch%3Amain)
[![image](https://codecov.io/gh/OpenSourceEconomics/tranquilo/branch/main/graph/badge.svg)](https://codecov.io/gh/OpenSourceEconomics/tranquilo)
[![image](https://results.pre-commit.ci/badge/github/OpenSourceEconomics/tranquilo/main.svg)](https://github.com/OpenSourceEconomics/tranquilo/actions?query=branch%3Amain)
[![image](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![image](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![image](https://pepy.tech/badge/tranquilo/month)](https://pepy.tech/project/tranquilo)
